FrameData class

A single captured frame

Constructors

FrameData({required double buildMs, required double rasterMs})

Properties

buildMs double
final
hashCode int
The hash code for this object.
no setterinherited
isJanky bool
final
rasterMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMs double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited