PerformanceCapture class

Captures performance data from the running Flutter app via VM service

Constructors

PerformanceCapture({required VmService vmService, required String isolateId})

Properties

hashCode int
The hash code for this object.
no setterinherited
isolateId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vmService → VmService
final

Methods

captureWindow({required String screenName, int durationMs = 2000}) Future<ScreenPerformance>
Quick snapshot — captures a 2 second window of frames
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startRecording() Future<void>
Start recording — call this before interacting with a screen
stopAndAnalyse(String screenName) Future<ScreenPerformance>
Stop recording and analyse — call this after screen interaction
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited