TreeAnalyser class

Constructors

TreeAnalyser()

Properties

hashCode int
The hash code for this object.
no setterinherited
issues List<WidgetIssue>
final
maxDepthFound int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalWidgets int
getter/setter pair
widgetCounts Map<String, int>
getter/setter pair

Methods

analyse(Map<String, dynamic> tree) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printSummary() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited