WidgetIssue class

Constructors

WidgetIssue({required String type, required String message, required String severity, String? file, int? line})

Properties

file String?
final
hashCode int
The hash code for this object.
no setterinherited
line int?
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited