InteractionEngine class

Constructors

InteractionEngine({required VmService vmService, required String isolateId, String? deviceId})

Properties

deviceId String?
final
hashCode int
The hash code for this object.
no setterinherited
isolateId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vmService → VmService
final

Methods

execute(List<PlannedInteraction> planned, String screenName) Future<List<InteractionResult>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
planInteractions(Map<String, dynamic> widgetTree) List<PlannedInteraction>
toReportSection(List<InteractionResult> results) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited