InteractionResult class
Constructors
- InteractionResult({required PlannedInteraction interaction, required bool executed, required String outcome, ScreenPerformance? performance, bool screenChanged = false})
Properties
- executed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction → PlannedInteraction
-
final
- outcome → String
-
final
- performance → ScreenPerformance?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenChanged → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited