PlannedInteraction class

Constructors

PlannedInteraction({required String widgetType, required InteractionType type, required String reason, String? widgetKey, String? label, String? file, int? line, String? testData, double? screenX, double? screenY})

Properties

file String?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
line int?
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenX double?
getter/setter pair
screenY double?
getter/setter pair
testData String?
final
type InteractionType
final
widgetKey String?
final
widgetType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited