deviceId property
ADB device ID (e.g. Z5BISOCMHEP7FAXG). Required for Phase 2 taps.
Pass an empty string or null to skip Phase 2.
Implementation
final String? deviceId;
ADB device ID (e.g. Z5BISOCMHEP7FAXG). Required for Phase 2 taps.
Pass an empty string or null to skip Phase 2.
final String? deviceId;