vmService property
VmService
vmService
final
Connected VM service used to read the widget tree and evaluate expressions.
Implementation
final VmService vmService;
Connected VM service used to read the widget tree and evaluate expressions.
final VmService vmService;