AppAnalysis class

Constructors

AppAnalysis({required String packageName, required String appClass, required String appArgs, required String appStateClass, required String? appStateInitMethod, required String? appStateTokenField, required String? appStateJwtField, required String? appStateUserIdField, required String? appStateUserNameField, required String? appStateEmailField, required bool hasFirebase, required String? firebaseOptionsImport, required List<String> routes, required String routerType, required String? routerVariable, required String stateManagement, required List<KnownRisk> knownRisks})

Properties

appArgs String
final
appClass String
final
appStateClass String
final
appStateEmailField String?
final
appStateInitMethod String?
final
appStateJwtField String?
final
appStateTokenField String?
final
appStateUserIdField String?
final
appStateUserNameField String?
final
firebaseOptionsImport String?
final
hasFirebase bool
final
hashCode int
The hash code for this object.
no setterinherited
knownRisks List<KnownRisk>
final
packageName String
final
routerType String
'gorouter' | 'getx' | 'autoroute' | 'beamer' | 'navigator1' | 'unknown'
final
routerVariable String?
Top-level variable name holding the router instance (e.g. '_router').
final
routes List<String>
final
runAppCall String
The full runApp call e.g. MyApp(allowDarkMode: true)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited