KnownRisk class

A risky code pattern detected by static analysis.

Constructors

KnownRisk({required String type, required String file, required int line, required String fieldName, required String callerMethod, required String description, required String suggestedFix})

Properties

callerMethod String
final
description String
final
fieldName String
final
file String
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedFix String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited