TestGenerator class

Constructors

TestGenerator({required String projectPath})

Properties

cachedAnalysis AppAnalysis?
Exposes the cached AppAnalysis (available after the first generateAndSave call).
no setter
hashCode int
The hash code for this object.
no setterinherited
projectPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateAndSave({required String screenName, required Map<String, dynamic> widgetTree, required List<InteractionResult> interactionResults, required List<WidgetIssue> issues}) Future<List<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited