HtmlReportGenerator class

Generates a self-contained HTML health report for all discovered screens and writes it to .dangi_doctor/report_<timestamp>.html in the project.

Constructors

HtmlReportGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate({required List<DiscoveredScreen> screens, required List<KnownRisk> knownRisks, required String projectPath, required String projectName}) Future<String>
Generate an HTML health report and auto-open it in the browser. Returns the path to the saved file.