ScreenPerformance class

Performance result for one screen

Constructors

ScreenPerformance({required String screenName, required List<FrameData> frames, required int memoryKb})

Properties

avgBuildMs double
no setter
avgRasterMs double
no setter
frames List<FrameData>
final
grade String
Performance grade based on jank rate and avg frame time
no setter
gradeEmoji String
no setter
hashCode int
The hash code for this object.
no setterinherited
jankRate double
no setter
jankyFrames int
no setter
memoryKb int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
final
totalFrames int
no setter
worstFrameMs double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printReport() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited