ScreenCrawler class
Constructors
- ScreenCrawler({String? projectPath, required String wsUrl})
Properties
Methods
-
captureWidgetTree(
{bool silent = false}) → Future< Map< String, dynamic> > -
connect(
) → Future< void> -
disconnect(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForAppReady(
) → Future< void> - Wait until the splash screen is gone and the real app is loaded.
-
waitForScreen(
String screenWidgetName, {int timeoutSeconds = 30}) → Future< bool> - Wait until a specific screen is visible in the widget tree. Polls every 500ms until the screen appears or times out.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited